pub struct StrandCamMkvSource<R: Read + Seek> {
pub parsed: ParsedStrandCamMkv,
/* private fields */
}Expand description
An MKV file saved by Strand Camera.
Note that this is not a general purpose MKV file converter but is specific to MKV files which have been saved by Strand Camera.
Fields
parsed: ParsedStrandCamMkvImplementations
Sourceimpl<R: Read + Seek> StrandCamMkvSource<R>
impl<R: Read + Seek> StrandCamMkvSource<R>
pub fn is_uncompressed(&self) -> bool